#!/bin/sh

. ./PLATFORM.sh

mkdir -p $SYS_PREFIX/bin
mkdir -p $SYS_PREFIX/lib
mkdir -p $SYS_PREFIX/include

src=`ls -1 *.tgz`

if [ ! $src -a `which wget` ]; then
  echo "==> No source found, attempting to download.."
  wget http://www.iro.umontreal.ca/~gambit/download/gambit/v4.6/source/gambc-v4_6_0.tgz
fi

src=`ls -1 *.tgz`

if [ ! $src ]; then
  echo "ERROR: gambit-c tarball missing."
  exit
fi

tmpdir=tmp_compile

if [ -d $tmpdir ]; then
rm -rf $tmpdir
fi
mkdir $tmpdir

here=`pwd`
cd $tmpdir
echo "==> Extracting source..."
tar -zxf ../$src 

echo "==> Configuring source..."
cd *
case $SYS_PLATFORM in
iphone*)
  EXTRAS=--host=arm
;;
maemo|android)
  EXTRAS=--host=arm-eabi
;;
win32*)
  EXTRAS=--host=i386-mingw32
;;
linux*)
  EXTRAS=--host=i386-linux
;;
*)
  EXTRAS=
;;
esac

EXTRAS="--enable-single-host $EXTRAS"

CC="$SYS_CC" AR="$SYS_AR" RANLIB="$SYS_RANLIB" ./configure --prefix="$SYS_PREFIX" $EXTRAS

echo "==> Patching source..."
patches=`ls -1 ../../*.patch`
for p in $patches; do
  patch -p0 < $p
done

echo "==> Compiling source..."
AR="$SYS_AR" RANLIB="$SYS_RANLIB" make

echo "==> Installing..."
make install
# copy out the minimals just in case the install fails (it will on android)
cp lib/libgambc.a $SYS_PREFIX/lib
cp include/gambit*.h $SYS_PREFIX/include
cd "$here"

echo "==> Cleaning up..."
rm -rf $tmpdir

echo "==> All done."
